| exp_clus_gpx | R Documentation |
Uses results from 'GPSeq_clus" to export .gpx file from specified AID and vector of desired cluster numbers for navigation during field site investigations.
exp_clus_gpx(AID, cn = "all", locs, cs, centroid_calc = "mean", dir = NULL)
AID |
Desired AID from sequential cluster output |
cn |
Numeric vector of desired cluster numbers to include in .gpx output, default is "all" |
locs |
Location dataframe output from GPSeq_clus() |
cs |
Cluster summary output from GPSeq_clus() |
centroid_calc |
'mean' (default) or 'median' centroid plot |
dir |
File path to save output |
.gpx file
exp_clus_gpx(AID = "ML1605M", cn = 4,
locs = GPSeq_clus(dat = ML_ex_dat[1:50,], search_radius_m = 200, window_days = 6,
clus_min_locs = 3, show_plots = c(FALSE, "mean"))[[1]],
cs = GPSeq_clus(dat = ML_ex_dat[1:50,], search_radius_m = 200, window_days = 6,
clus_min_locs = 3, show_plots = c(FALSE, "mean"))[[2]],
dir= tempdir()
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.